==> pyensembl-0.4.0.tar.gz: pyensembl-0.4.0/test/test_locus.py <==
from pyensembl.locus import normalize_chromosome, Locus

from nose.tools import assert_raises


def test_normalize_chromosome():
    assert normalize_chromosome("X") == "X"
    assert normalize_chromosome("chrX") == "X"
    assert normalize_chromosome("x") == "X"

    assert normalize_chromosome(1) == "1"
    assert normalize_chromosome("1") == "1"
    assert normalize_chromosome("chr1") == "1"

    assert normalize_chromosome("chrM") == "MT"
    assert normalize_chromosome("chrMT") == "MT"
    assert normalize_chromosome("M") == "MT"
    assert normalize_chromosome("MT") == "MT"

    with assert_raises(TypeError):
        normalize_chromosome({"a":"b"})

    with assert_raises(TypeError):
        normalize_chromosome([])

    with assert_raises(TypeError):
        normalize_chromosome(None)

    with assert_raises(ValueError):
        normalize_chromosome("")

    with assert_raises(ValueError):
        normalize_chromosome(0)

def test_locus_overlaps():
    locus = Locus("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20)
    assert locus.overlaps("1", 5, 30)
    assert locus.overlaps("1", 15, 16)
    assert locus.overlaps("1", 15, 30)
    assert locus.overlaps("1", 5, 15)
    assert locus.overlaps("1", 10, 10)
    assert locus.overlaps("1", 20, 20)
    # before start
    assert not locus.overlaps(1,9)
    # after end
    assert not locus.overlaps(21, 30)
    # wrong contig
    assert not locus.overlaps("2", 10, 20)
    # wrong strand
    assert not locus.overlaps("1", 10, 20, "-")

def test_locus_overlaps():
    locus = Locus("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20)
    assert locus.overlaps("1", 15, 16)
    assert locus.overlaps("1", 10, 10)
    assert locus.overlaps("1", 20, 20)
    assert locus.overlaps("1", 5, 30)
    assert locus.overlaps("1", 15, 30)
    assert locus.overlaps("1", 5, 15)

    # before start
    assert not locus.overlaps("1", 1,9)

    # after end
    assert not locus.overlaps("1", 21, 30)

    # wrong contig
    assert not locus.overlaps("2", 10, 20)

    # wrong strand
    assert not locus.overlaps("1", 10, 20, "-")


def test_locus_contains():
    locus = Locus("1", 10, 20, "+")
    assert locus.contains("1", 10, 20, "+")
    assert locus.contains("1", 10, 20)
    assert locus.contains("1", 15, 16)
    assert locus.contains("1", 10, 10)
    assert locus.contains("1", 20, 20)


    # before start and after end
    assert not locus.contains("1", 5, 30)

    # before start
    assert not locus.contains("1", 1,9)
    assert not locus.contains("1", 5, 15)

    # after end
    assert not locus.contains("1", 21, 30)
    assert not locus.contains("1", 15, 30)

    # wrong contig
    assert not locus.contains("2", 10, 20)

    # wrong strand
    assert not locus.contains("1", 10, 20, "-")

==> pyensembl-0.5.0.tar.gz: pyensembl-0.5.0/test/test_locus.py <==
from pyensembl.locus import normalize_chromosome, Locus

from nose.tools import assert_raises


def test_normalize_chromosome():
    assert normalize_chromosome("X") == "X"
    assert normalize_chromosome("chrX") == "X"
    assert normalize_chromosome("x") == "X"

    assert normalize_chromosome(1) == "1"
    assert normalize_chromosome("1") == "1"
    assert normalize_chromosome("chr1") == "1"

    assert normalize_chromosome("chrM") == "MT"
    assert normalize_chromosome("chrMT") == "MT"
    assert normalize_chromosome("M") == "MT"
    assert normalize_chromosome("MT") == "MT"

    with assert_raises(TypeError):
        normalize_chromosome({"a":"b"})

    with assert_raises(TypeError):
        normalize_chromosome([])

    with assert_raises(TypeError):
        normalize_chromosome(None)

    with assert_raises(ValueError):
        normalize_chromosome("")

    with assert_raises(ValueError):
        normalize_chromosome(0)

def test_locus_overlaps():
    locus = Locus("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20)
    assert locus.overlaps("1", 5, 30)
    assert locus.overlaps("1", 15, 16)
    assert locus.overlaps("1", 15, 30)
    assert locus.overlaps("1", 5, 15)
    assert locus.overlaps("1", 10, 10)
    assert locus.overlaps("1", 20, 20)
    # before start
    assert not locus.overlaps(1,9)
    # after end
    assert not locus.overlaps(21, 30)
    # wrong contig
    assert not locus.overlaps("2", 10, 20)
    # wrong strand
    assert not locus.overlaps("1", 10, 20, "-")

def test_locus_overlaps():
    locus = Locus("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20, "+")
    assert locus.overlaps("1", 10, 20)
    assert locus.overlaps("1", 15, 16)
    assert locus.overlaps("1", 10, 10)
    assert locus.overlaps("1", 20, 20)
    assert locus.overlaps("1", 5, 30)
    assert locus.overlaps("1", 15, 30)
    assert locus.overlaps("1", 5, 15)

    # before start
    assert not locus.overlaps("1", 1,9)

    # after end
    assert not locus.overlaps("1", 21, 30)

    # wrong contig
    assert not locus.overlaps("2", 10, 20)

    # wrong strand
    assert not locus.overlaps("1", 10, 20, "-")


def test_locus_contains():
    locus = Locus("1", 10, 20, "+")
    assert locus.contains("1", 10, 20, "+")
    assert locus.contains("1", 10, 20)
    assert locus.contains("1", 15, 16)
    assert locus.contains("1", 10, 10)
    assert locus.contains("1", 20, 20)


    # before start and after end
    assert not locus.contains("1", 5, 30)

    # before start
    assert not locus.contains("1", 1,9)
    assert not locus.contains("1", 5, 15)

    # after end
    assert not locus.contains("1", 21, 30)
    assert not locus.contains("1", 15, 30)

    # wrong contig
    assert not locus.contains("2", 10, 20)

    # wrong strand
    assert not locus.contains("1", 10, 20, "-")

def test_position_offset():
    forward_locus = Locus("1", 10, 20, "+")
    assert forward_locus.position_offset(10) == 0
    assert forward_locus.position_offset(15) == 5
    assert forward_locus.position_offset(19) == 9
    assert forward_locus.position_offset(20) == 10

    negative_locus = Locus("1", 10, 20, "-")
    assert negative_locus.position_offset(10) == 10
    assert negative_locus.position_offset(15) == 5
    assert negative_locus.position_offset(19) == 1
    assert negative_locus.position_offset(20) == 0

    # don't allow negative offsets
    with assert_raises(ValueError):
        forward_locus.position_offset(9)

    # don't allow negative offsets
    with assert_raises(ValueError):
        negative_locus.position_offset(9)

    # don't allow offset past the end of the locus
    with assert_raises(ValueError):
        forward_locus.position_offset(21)

    # don't allow offset past the end of the locus
    with assert_raises(ValueError):
        negative_locus.position_offset(21)


def test_range_offset():
    forward_locus = Locus("1", 10, 20, "+")
    assert forward_locus.range_offset(10, 20) == (0, 10)
    assert forward_locus.range_offset(11, 14) == (1, 4)
    assert forward_locus.range_offset(20, 20) == (10, 10)

    negative_locus = Locus("1", 10, 20, "-")
    assert negative_locus.range_offset(10, 20) == (0, 10)
    assert negative_locus.range_offset(11, 14) == (6, 9)
    assert negative_locus.range_offset(20, 20) == (0, 0)

    # start shouldn't be larger than end
    with assert_raises(AssertionError):
        forward_locus.range_offset(21, 20)

    # start shouldn't be larger than end
    with assert_raises(AssertionError):
        negative_locus.range_offset(21, 20)

    # don't allow negative offsets
    with assert_raises(ValueError):
        forward_locus.range_offset(9, 10)

    # don't allow negative offsets
    with assert_raises(ValueError):
        forward_locus.range_offset(9, 10)

    # don't allow negative offsets
    with assert_raises(ValueError):
        negative_locus.range_offset(9, 10)
